==> webknossos-0.9.18.tar.gz: webknossos-0.9.18/webknossos/client/_generated/models/__init__.py <==
""" Contains all the data models used in inputs/outputs """

from .action import Action
from .action_annotation_layer_parameters import ActionAnnotationLayerParameters
from .action_any_content import ActionAnyContent
from .action_cancel_upload_information import ActionCancelUploadInformation
from .action_js_value import ActionJsValue
from .action_multipart_form_data_temporary_file import (
    ActionMultipartFormDataTemporaryFile,
)
from .action_reserve_upload_information import ActionReserveUploadInformation
from .action_upload_information import ActionUploadInformation
from .annotation_info_response_200 import AnnotationInfoResponse200
from .annotation_info_response_200_annotation_layers_item import (
    AnnotationInfoResponse200AnnotationLayersItem,
)
from .annotation_info_response_200_data_store import AnnotationInfoResponse200DataStore
from .annotation_info_response_200_restrictions import (
    AnnotationInfoResponse200Restrictions,
)
from .annotation_info_response_200_settings import AnnotationInfoResponse200Settings
from .annotation_info_response_200_settings_resolution_restrictions import (
    AnnotationInfoResponse200SettingsResolutionRestrictions,
)
from .annotation_info_response_200_stats import AnnotationInfoResponse200Stats
from .annotation_info_response_200_task import AnnotationInfoResponse200Task
from .annotation_info_response_200_task_needed_experience import (
    AnnotationInfoResponse200TaskNeededExperience,
)
from .annotation_info_response_200_task_status import (
    AnnotationInfoResponse200TaskStatus,
)
from .annotation_info_response_200_task_type import AnnotationInfoResponse200TaskType
from .annotation_info_response_200_task_type_settings import (
    AnnotationInfoResponse200TaskTypeSettings,
)
from .annotation_info_response_200_task_type_settings_resolution_restrictions import (
    AnnotationInfoResponse200TaskTypeSettingsResolutionRestrictions,
)
from .annotation_info_response_200_tracing_store import (
    AnnotationInfoResponse200TracingStore,
)
from .annotation_info_response_200_user import AnnotationInfoResponse200User
from .annotation_info_response_200_user_teams_item import (
    AnnotationInfoResponse200UserTeamsItem,
)
from .annotation_infos_by_task_id_response_200_item import (
    AnnotationInfosByTaskIdResponse200Item,
)
from .annotation_infos_by_task_id_response_200_item_annotation_layers_item import (
    AnnotationInfosByTaskIdResponse200ItemAnnotationLayersItem,
)
from .annotation_infos_by_task_id_response_200_item_data_store import (
    AnnotationInfosByTaskIdResponse200ItemDataStore,
)
from .annotation_infos_by_task_id_response_200_item_restrictions import (
    AnnotationInfosByTaskIdResponse200ItemRestrictions,
)
from .annotation_infos_by_task_id_response_200_item_settings import (
    AnnotationInfosByTaskIdResponse200ItemSettings,
)
from .annotation_infos_by_task_id_response_200_item_settings_resolution_restrictions import (
    AnnotationInfosByTaskIdResponse200ItemSettingsResolutionRestrictions,
)
from .annotation_infos_by_task_id_response_200_item_stats import (
    AnnotationInfosByTaskIdResponse200ItemStats,
)
from .annotation_infos_by_task_id_response_200_item_task import (
    AnnotationInfosByTaskIdResponse200ItemTask,
)
from .annotation_infos_by_task_id_response_200_item_task_needed_experience import (
    AnnotationInfosByTaskIdResponse200ItemTaskNeededExperience,
)
from .annotation_infos_by_task_id_response_200_item_task_status import (
    AnnotationInfosByTaskIdResponse200ItemTaskStatus,
)
from .annotation_infos_by_task_id_response_200_item_task_type import (
    AnnotationInfosByTaskIdResponse200ItemTaskType,
)
from .annotation_infos_by_task_id_response_200_item_task_type_settings import (
    AnnotationInfosByTaskIdResponse200ItemTaskTypeSettings,
)
from .annotation_infos_by_task_id_response_200_item_task_type_settings_resolution_restrictions import (
    AnnotationInfosByTaskIdResponse200ItemTaskTypeSettingsResolutionRestrictions,
)
from .annotation_infos_by_task_id_response_200_item_tracing_store import (
    AnnotationInfosByTaskIdResponse200ItemTracingStore,
)
from .annotation_infos_by_task_id_response_200_item_user import (
    AnnotationInfosByTaskIdResponse200ItemUser,
)
from .annotation_infos_by_task_id_response_200_item_user_teams_item import (
    AnnotationInfosByTaskIdResponse200ItemUserTeamsItem,
)
from .build_info_response_200 import BuildInfoResponse200
from .build_info_response_200_webknossos import BuildInfoResponse200Webknossos
from .build_info_response_200_webknossos_wrap import BuildInfoResponse200WebknossosWrap
from .create_project_json_body import CreateProjectJsonBody
from .current_user_info_response_200 import CurrentUserInfoResponse200
from .current_user_info_response_200_experiences import (
    CurrentUserInfoResponse200Experiences,
)
from .current_user_info_response_200_novel_user_experience_infos import (
    CurrentUserInfoResponse200NovelUserExperienceInfos,
)
from .current_user_info_response_200_teams_item import (
    CurrentUserInfoResponse200TeamsItem,
)
from .dataset_cancel_upload_json_body import DatasetCancelUploadJsonBody
from .dataset_finish_upload_json_body import DatasetFinishUploadJsonBody
from .dataset_info_response_200 import DatasetInfoResponse200
from .dataset_info_response_200_allowed_teams_item import (
    DatasetInfoResponse200AllowedTeamsItem,
)
from .dataset_info_response_200_data_source import DatasetInfoResponse200DataSource
from .dataset_info_response_200_data_source_data_layers_item import (
    DatasetInfoResponse200DataSourceDataLayersItem,
)
from .dataset_info_response_200_data_source_data_layers_item_bounding_box import (
    DatasetInfoResponse200DataSourceDataLayersItemBoundingBox,
)
from .dataset_info_response_200_data_source_data_layers_item_default_view_configuration import (
    DatasetInfoResponse200DataSourceDataLayersItemDefaultViewConfiguration,
)
from .dataset_info_response_200_data_source_id import DatasetInfoResponse200DataSourceId
from .dataset_info_response_200_data_store import DatasetInfoResponse200DataStore
from .dataset_reserve_upload_json_body import DatasetReserveUploadJsonBody
from .datastore_list_response_200_item import DatastoreListResponse200Item
from .generate_token_for_data_store_response_200 import (
    GenerateTokenForDataStoreResponse200,
)
from .project_info_by_id_response_200 import ProjectInfoByIdResponse200
from .project_info_by_id_response_200_owner import ProjectInfoByIdResponse200Owner
from .project_info_by_id_response_200_owner_teams_item import (
    ProjectInfoByIdResponse200OwnerTeamsItem,
)
from .project_info_by_name_response_200 import ProjectInfoByNameResponse200
from .project_info_by_name_response_200_owner import ProjectInfoByNameResponse200Owner
from .project_info_by_name_response_200_owner_teams_item import (
    ProjectInfoByNameResponse200OwnerTeamsItem,
)
from .task_create_from_files_json_body import TaskCreateFromFilesJsonBody
from .task_info_response_200 import TaskInfoResponse200
from .task_info_response_200_needed_experience import (
    TaskInfoResponse200NeededExperience,
)
from .task_info_response_200_status import TaskInfoResponse200Status
from .task_info_response_200_type import TaskInfoResponse200Type
from .task_info_response_200_type_settings import TaskInfoResponse200TypeSettings
from .task_info_response_200_type_settings_resolution_restrictions import (
    TaskInfoResponse200TypeSettingsResolutionRestrictions,
)
from .task_infos_by_project_id_response_200_item import (
    TaskInfosByProjectIdResponse200Item,
)
from .task_infos_by_project_id_response_200_item_needed_experience import (
    TaskInfosByProjectIdResponse200ItemNeededExperience,
)
from .task_infos_by_project_id_response_200_item_status import (
    TaskInfosByProjectIdResponse200ItemStatus,
)
from .task_infos_by_project_id_response_200_item_type import (
    TaskInfosByProjectIdResponse200ItemType,
)
from .task_infos_by_project_id_response_200_item_type_settings import (
    TaskInfosByProjectIdResponse200ItemTypeSettings,
)
from .task_infos_by_project_id_response_200_item_type_settings_resolution_restrictions import (
    TaskInfosByProjectIdResponse200ItemTypeSettingsResolutionRestrictions,
)
from .user_info_by_id_response_200 import UserInfoByIdResponse200
from .user_info_by_id_response_200_experiences import UserInfoByIdResponse200Experiences
from .user_info_by_id_response_200_novel_user_experience_infos import (
    UserInfoByIdResponse200NovelUserExperienceInfos,
)
from .user_info_by_id_response_200_teams_item import UserInfoByIdResponse200TeamsItem
from .user_list_response_200_item import UserListResponse200Item
from .user_list_response_200_item_experiences import UserListResponse200ItemExperiences
from .user_list_response_200_item_novel_user_experience_infos import (
    UserListResponse200ItemNovelUserExperienceInfos,
)
from .user_list_response_200_item_teams_item import UserListResponse200ItemTeamsItem
from .user_logged_time_response_200 import UserLoggedTimeResponse200
from .user_logged_time_response_200_logged_time_item import (
    UserLoggedTimeResponse200LoggedTimeItem,
)
from .user_logged_time_response_200_logged_time_item_payment_interval import (
    UserLoggedTimeResponse200LoggedTimeItemPaymentInterval,
)

==> webknossos-0.10.1.tar.gz: webknossos-0.10.1/webknossos/client/_generated/models/__init__.py <==
""" Contains all the data models used in inputs/outputs """

from .action import Action
from .action_annotation_layer_parameters import ActionAnnotationLayerParameters
from .action_any_content import ActionAnyContent
from .action_cancel_upload_information import ActionCancelUploadInformation
from .action_js_value import ActionJsValue
from .action_multipart_form_data_temporary_file import (
    ActionMultipartFormDataTemporaryFile,
)
from .action_reserve_upload_information import ActionReserveUploadInformation
from .action_upload_information import ActionUploadInformation
from .annotation_info_response_200 import AnnotationInfoResponse200
from .annotation_info_response_200_annotation_layers_item import (
    AnnotationInfoResponse200AnnotationLayersItem,
)
from .annotation_info_response_200_data_store import AnnotationInfoResponse200DataStore
from .annotation_info_response_200_restrictions import (
    AnnotationInfoResponse200Restrictions,
)
from .annotation_info_response_200_settings import AnnotationInfoResponse200Settings
from .annotation_info_response_200_settings_resolution_restrictions import (
    AnnotationInfoResponse200SettingsResolutionRestrictions,
)
from .annotation_info_response_200_stats import AnnotationInfoResponse200Stats
from .annotation_info_response_200_task import AnnotationInfoResponse200Task
from .annotation_info_response_200_task_needed_experience import (
    AnnotationInfoResponse200TaskNeededExperience,
)
from .annotation_info_response_200_task_status import (
    AnnotationInfoResponse200TaskStatus,
)
from .annotation_info_response_200_task_type import AnnotationInfoResponse200TaskType
from .annotation_info_response_200_task_type_settings import (
    AnnotationInfoResponse200TaskTypeSettings,
)
from .annotation_info_response_200_task_type_settings_resolution_restrictions import (
    AnnotationInfoResponse200TaskTypeSettingsResolutionRestrictions,
)
from .annotation_info_response_200_tracing_store import (
    AnnotationInfoResponse200TracingStore,
)
from .annotation_info_response_200_user import AnnotationInfoResponse200User
from .annotation_info_response_200_user_teams_item import (
    AnnotationInfoResponse200UserTeamsItem,
)
from .annotation_infos_by_task_id_response_200_item import (
    AnnotationInfosByTaskIdResponse200Item,
)
from .annotation_infos_by_task_id_response_200_item_annotation_layers_item import (
    AnnotationInfosByTaskIdResponse200ItemAnnotationLayersItem,
)
from .annotation_infos_by_task_id_response_200_item_data_store import (
    AnnotationInfosByTaskIdResponse200ItemDataStore,
)
from .annotation_infos_by_task_id_response_200_item_restrictions import (
    AnnotationInfosByTaskIdResponse200ItemRestrictions,
)
from .annotation_infos_by_task_id_response_200_item_settings import (
    AnnotationInfosByTaskIdResponse200ItemSettings,
)
from .annotation_infos_by_task_id_response_200_item_settings_resolution_restrictions import (
    AnnotationInfosByTaskIdResponse200ItemSettingsResolutionRestrictions,
)
from .annotation_infos_by_task_id_response_200_item_stats import (
    AnnotationInfosByTaskIdResponse200ItemStats,
)
from .annotation_infos_by_task_id_response_200_item_task import (
    AnnotationInfosByTaskIdResponse200ItemTask,
)
from .annotation_infos_by_task_id_response_200_item_task_needed_experience import (
    AnnotationInfosByTaskIdResponse200ItemTaskNeededExperience,
)
from .annotation_infos_by_task_id_response_200_item_task_status import (
    AnnotationInfosByTaskIdResponse200ItemTaskStatus,
)
from .annotation_infos_by_task_id_response_200_item_task_type import (
    AnnotationInfosByTaskIdResponse200ItemTaskType,
)
from .annotation_infos_by_task_id_response_200_item_task_type_settings import (
    AnnotationInfosByTaskIdResponse200ItemTaskTypeSettings,
)
from .annotation_infos_by_task_id_response_200_item_task_type_settings_resolution_restrictions import (
    AnnotationInfosByTaskIdResponse200ItemTaskTypeSettingsResolutionRestrictions,
)
from .annotation_infos_by_task_id_response_200_item_tracing_store import (
    AnnotationInfosByTaskIdResponse200ItemTracingStore,
)
from .annotation_infos_by_task_id_response_200_item_user import (
    AnnotationInfosByTaskIdResponse200ItemUser,
)
from .annotation_infos_by_task_id_response_200_item_user_teams_item import (
    AnnotationInfosByTaskIdResponse200ItemUserTeamsItem,
)
from .build_info_response_200 import BuildInfoResponse200
from .build_info_response_200_webknossos import BuildInfoResponse200Webknossos
from .build_info_response_200_webknossos_wrap import BuildInfoResponse200WebknossosWrap
from .create_project_json_body import CreateProjectJsonBody
from .current_user_info_response_200 import CurrentUserInfoResponse200
from .current_user_info_response_200_experiences import (
    CurrentUserInfoResponse200Experiences,
)
from .current_user_info_response_200_novel_user_experience_infos import (
    CurrentUserInfoResponse200NovelUserExperienceInfos,
)
from .current_user_info_response_200_teams_item import (
    CurrentUserInfoResponse200TeamsItem,
)
from .dataset_cancel_upload_json_body import DatasetCancelUploadJsonBody
from .dataset_finish_upload_json_body import DatasetFinishUploadJsonBody
from .dataset_info_response_200 import DatasetInfoResponse200
from .dataset_info_response_200_allowed_teams_item import (
    DatasetInfoResponse200AllowedTeamsItem,
)
from .dataset_info_response_200_data_source import DatasetInfoResponse200DataSource
from .dataset_info_response_200_data_source_data_layers_item import (
    DatasetInfoResponse200DataSourceDataLayersItem,
)
from .dataset_info_response_200_data_source_data_layers_item_bounding_box import (
    DatasetInfoResponse200DataSourceDataLayersItemBoundingBox,
)
from .dataset_info_response_200_data_source_data_layers_item_default_view_configuration import (
    DatasetInfoResponse200DataSourceDataLayersItemDefaultViewConfiguration,
)
from .dataset_info_response_200_data_source_id import DatasetInfoResponse200DataSourceId
from .dataset_info_response_200_data_store import DatasetInfoResponse200DataStore
from .dataset_reserve_upload_json_body import DatasetReserveUploadJsonBody
from .dataset_sharing_token_response_200 import DatasetSharingTokenResponse200
from .dataset_update_json_body import DatasetUpdateJsonBody
from .datastore_list_response_200_item import DatastoreListResponse200Item
from .generate_token_for_data_store_response_200 import (
    GenerateTokenForDataStoreResponse200,
)
from .project_info_by_id_response_200 import ProjectInfoByIdResponse200
from .project_info_by_id_response_200_owner import ProjectInfoByIdResponse200Owner
from .project_info_by_id_response_200_owner_teams_item import (
    ProjectInfoByIdResponse200OwnerTeamsItem,
)
from .project_info_by_name_response_200 import ProjectInfoByNameResponse200
from .project_info_by_name_response_200_owner import ProjectInfoByNameResponse200Owner
from .project_info_by_name_response_200_owner_teams_item import (
    ProjectInfoByNameResponse200OwnerTeamsItem,
)
from .task_create_from_files_json_body import TaskCreateFromFilesJsonBody
from .task_info_response_200 import TaskInfoResponse200
from .task_info_response_200_needed_experience import (
    TaskInfoResponse200NeededExperience,
)
from .task_info_response_200_status import TaskInfoResponse200Status
from .task_info_response_200_type import TaskInfoResponse200Type
from .task_info_response_200_type_settings import TaskInfoResponse200TypeSettings
from .task_info_response_200_type_settings_resolution_restrictions import (
    TaskInfoResponse200TypeSettingsResolutionRestrictions,
)
from .task_infos_by_project_id_response_200_item import (
    TaskInfosByProjectIdResponse200Item,
)
from .task_infos_by_project_id_response_200_item_needed_experience import (
    TaskInfosByProjectIdResponse200ItemNeededExperience,
)
from .task_infos_by_project_id_response_200_item_status import (
    TaskInfosByProjectIdResponse200ItemStatus,
)
from .task_infos_by_project_id_response_200_item_type import (
    TaskInfosByProjectIdResponse200ItemType,
)
from .task_infos_by_project_id_response_200_item_type_settings import (
    TaskInfosByProjectIdResponse200ItemTypeSettings,
)
from .task_infos_by_project_id_response_200_item_type_settings_resolution_restrictions import (
    TaskInfosByProjectIdResponse200ItemTypeSettingsResolutionRestrictions,
)
from .user_info_by_id_response_200 import UserInfoByIdResponse200
from .user_info_by_id_response_200_experiences import UserInfoByIdResponse200Experiences
from .user_info_by_id_response_200_novel_user_experience_infos import (
    UserInfoByIdResponse200NovelUserExperienceInfos,
)
from .user_info_by_id_response_200_teams_item import UserInfoByIdResponse200TeamsItem
from .user_list_response_200_item import UserListResponse200Item
from .user_list_response_200_item_experiences import UserListResponse200ItemExperiences
from .user_list_response_200_item_novel_user_experience_infos import (
    UserListResponse200ItemNovelUserExperienceInfos,
)
from .user_list_response_200_item_teams_item import UserListResponse200ItemTeamsItem
from .user_logged_time_response_200 import UserLoggedTimeResponse200
from .user_logged_time_response_200_logged_time_item import (
    UserLoggedTimeResponse200LoggedTimeItem,
)
from .user_logged_time_response_200_logged_time_item_payment_interval import (
    UserLoggedTimeResponse200LoggedTimeItemPaymentInterval,
)
